/* dialog.cpp
 *
 * Pieter Eendebak <pte@ddsw.nl>
 */

#include "includes.h"
#include "dialog.moc"
#include "kgo.h"
#include "go_board.h"

#define ADD_LABEL( label, str, x, y, w, h ) \
	{	label = new QLabel(str, this); \
		label->setGeometry(x, y, w, h); \
	}

#define ADD_INT_LINE( line, value, x, y, w, h ) \
	{	line = new KIntegerLine( this); \
		line->setValue( value ) ; \
		line->setGeometry(x, y, w, h); \
	}

/* ##########################
 * #	class TimeDialog    #
 * ##########################
 */
TimeDialog::TimeDialog( const char *text, long time, QWidget * )
	: QDialog( 0, 0, FALSE, WStyle_NoBorder )
{
	QLabel *t ;
	ADD_LABEL( t, text, 10, 10, 200, 30 ) ;
	QSize s = t->sizeHint() ;
	t->setGeometry( 10, 10, s.width()+5, s.height()+5 ) ;

	startTimer( time ) ;
	adjustSize() ; 
}

void TimeDialog::timerEvent( QTimerEvent * )
{
	delete this ;
}

/* ##########################
 * #	class SignalDialog  #
 * ##########################
 */
SignalDialog::SignalDialog( const char *text )
	: QDialog( 0, 0, FALSE, WStyle_NoBorder )
{
	QLabel *t ;
	ADD_LABEL( t, text, 10, 10, 200, 30 ) ;
	QSize s = t->sizeHint() ;
	t->setGeometry( 10, 10, s.width()+5, s.height()+5 ) ;

	adjustSize() ; 
}

/* ##########################
 * #	class NewGame       #
 * ##########################
 */

NewGame::NewGame( QWidget *parent )
        : QDialog( parent, 0, TRUE)
{
	// debug("creating NewGame dialog") ;

	setCaption( klocale->translate("Select game type to play") ) ;

	choice = new QComboBox( this ) ;
	choice->insertItem( klocale->translate( "Play against the computer"),
				COMPUTER_GAME ) ;
 	choice->insertItem( klocale->translate( "Play with two people"),
			TWO_PLAYER_GAME ) ;
 	choice->insertItem( klocale->translate( "Play over the Internet"),
			 NETWORK_GAME );
	choice->setGeometry( 10, 10, 220, 30 ) ;

	QLabel *xW, *yW ;
	
	ADD_LABEL( xW, i18n("Width of the board"),
			10, 60, 140, 20 ) ;
	ADD_LABEL( yW, i18n("Height of the board"),
			10, 90, 140, 20 ) ;
 	ADD_INT_LINE( xWidth, DEFAULT_X_SIZE, 160, 60, 60, 20 ) ; 
	ADD_INT_LINE( yWidth, DEFAULT_Y_SIZE, 160, 90, 60, 20 ) ;
#ifndef DEBUG
	xWidth->setEnabled( false ) ; 
	yWidth->setEnabled( false ) ; 
#endif
        QPushButton *ok, *cancel;  
	ok = new QPushButton( "Ok", this );
        connect( ok, SIGNAL(clicked()), SLOT(accept()) );
	cancel = new QPushButton( "Cancel", this );
	connect( cancel, SIGNAL(clicked()), SLOT(reject()) ); 

        ok->setGeometry( 10, 140, 80 ,30 );
 	cancel->setGeometry( 100, 140, 80 ,30 );  

	adjustSize() ;
}

NewGame::~NewGame()
{
}

int NewGame::getGameType()
{
	return choice->currentItem() ;	 
}

int NewGame::getXSize()
{
	return xWidth->value() ;
}

int NewGame::getYSize()
{
	return yWidth->value() ;
}

/* ##########################
 * #	class GameOver	    #
 * ##########################
 */

GameOver::GameOver( QWidget *parent, const char *name )
        : QDialog( parent, name, TRUE )
{
	setCaption( klocale->translate("Game ended") ) ;

	txt = new QLabel( klocale->translate(
		"The game has ended.\nPlease choose one of the options below" 
					),
			this
			) ; 
  	count = new QPushButton( klocale->translate("Count scores"), this );
        connect( count, SIGNAL(clicked()), SLOT(Count()) );
        newgame = new QPushButton( klocale->translate("Start new game"), this );
  	connect( newgame, SIGNAL(clicked()), SLOT(Newgame()) ); 

	const int b = 100 ;
	const int width=20 + 2*b + 60 ;
	const int height=100 ;
	txt->setGeometry( 10, 10, width-20, 40 ) ;
        count->setGeometry( 10, 50, b ,30 );
 	newgame->setGeometry( width-10-b, 50, b ,30 );  

	resize( width, height ) ;
}

GameOver::~GameOver()
{
}

void GameOver::Count()
{
	done( COUNT ) ;
}

void GameOver::Newgame()
{
	done( NEWGAME ) ;
}

void GameOver::Quit()
{
	done( QUIT ) ;
}

